"""
Independent Reserve features a JSON based API, that is comprised of Public and Private methods.

All API calls must be made over SSL to https://api.independentreserve.com .
Public methods do not require an authentication token and should be accessed via HTTP GET.
Private methods require a valid authentication token and must be accessed via HTTP POST.
Errors are returned to the caller as a HTTP 400 return code and a descriptive error message.
Ensure that the contentType of the your JSON POST request is set to 'application/json'.
Fiat currency amounts cannot have more than 2 decimal places, and XBT amounts cannot have more than 8 decimal places.
"""
from .public import *
from .authentication import *
from .private import *
from .websocket import *


import websockets
import asyncio
import sys


async def wss_subscribe(queue: asyncio.Queue, channel_name: list = ["ticker-xbt-aud"]):
    try:
        if len(channel_name) > 1:
            channel = ",".join(channel_name)
        else:
            channel = channel_name[0]
        WSS_URL = f"wss://websockets.independentreserve.com?subscribe={channel}"
        async with websockets.connect(WSS_URL) as websocket:
            while True:
                data = await websocket.recv()
                data = data.encode("utf-8")
                await queue.put(data)
    except Exception as error:
        print(error)
        sys.exit(1)



# Melchi
from setuptools import setup, find_packages

setup(
    name="pyindependentreserve",
    version="0.4.1",
    description="Python client for Interacting with Independent Reserve API - The Bitcoin and Digital Currency Market",
    long_description=open("README.md", "r").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/MelchiSalins/pyindependentreserve",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
    ],
    keywords="Bitcoin BlockChain Crypto-currency",
    author="Melchi Salins",
    author_email="melchisalins@gmail.com",
    license="MIT",
    packages=find_packages(),
    install_requires=["requests>=2.22.0", "websockets==9.1"],
    include_package_data=True,
    zip_safe=True,
)
